Documentation
¶
Index ¶
- Constants
- Variables
- type Bot
- func (b *Bot) AddMessage(ctx context.Context, tx pgx.Tx, params []schema.AddMessageParams, ...) error
- func (b *Bot) AddThreadMessages(ctx context.Context, tx pgx.Tx, params []schema.AddThreadMessageParams, ...) error
- func (b *Bot) EnsureChannel(ctx context.Context, tx pgx.Tx, channelID string) (bool, error)
- func (b *Bot) GetChannel(ctx context.Context, channelID string) (schema.ChannelsV2, error)
- func (b *Bot) GetMessage(ctx context.Context, channelID string, slackTs string) (schema.GetMessageRow, error)
- func (b *Bot) Init(riverClient *river.Client[pgx.Tx], docsConfig *docs.Config) error
- func (b *Bot) NotifyMessage(ctx context.Context, ev *slackevents.MessageEvent) error
- func (b *Bot) NotifyReactionAdded(ctx context.Context, ev *slackevents.ReactionAddedEvent) error
- func (b *Bot) NotifyReactionRemoved(ctx context.Context, ev *slackevents.ReactionRemovedEvent) error
- func (b *Bot) UpdateChannel(ctx context.Context, tx pgx.Tx, params schema.UpdateChannelAttrsParams) error
Constants ¶
const (
SourceBackfill messageSource
)
Variables ¶
var (
ErrMessageNotFound = errors.New("message not found")
)
Functions ¶
This section is empty.
Types ¶
type Bot ¶
func (*Bot) AddMessage ¶
func (*Bot) AddThreadMessages ¶
func (*Bot) EnsureChannel ¶ added in v0.0.23
func (*Bot) GetChannel ¶ added in v0.0.23
func (*Bot) GetMessage ¶
func (*Bot) NotifyMessage ¶ added in v0.0.6
func (b *Bot) NotifyMessage(ctx context.Context, ev *slackevents.MessageEvent) error
func (*Bot) NotifyReactionAdded ¶ added in v0.0.6
func (b *Bot) NotifyReactionAdded(ctx context.Context, ev *slackevents.ReactionAddedEvent) error
func (*Bot) NotifyReactionRemoved ¶ added in v0.0.6
func (b *Bot) NotifyReactionRemoved(ctx context.Context, ev *slackevents.ReactionRemovedEvent) error
func (*Bot) UpdateChannel ¶
Directories
¶
| Path | Synopsis |
|---|---|
|
mocks
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
|
otel
|
|
|
semconv
Standardized attribute keys and values for use in all OpenTelemetry signals Before adding a new attribute, first check to see if an attribute is already defined in the OpenTelemetry spec (https://opentelemetry.io/docs/specs/semconv/)
|
Standardized attribute keys and values for use in all OpenTelemetry signals Before adding a new attribute, first check to see if an attribute is already defined in the OpenTelemetry spec (https://opentelemetry.io/docs/specs/semconv/) |
|
mocks
Package mocks is a generated GoMock package.
|
Package mocks is a generated GoMock package. |
Click to show internal directories.
Click to hide internal directories.